==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/NumericAxisBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AxisDescriptionMetadata } from "./AxisDescriptionMetadata";
/**
 * @hidden
 */
var NumericAxisBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NumericAxisBaseDescriptionMetadata, _super);
    function NumericAxisBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NumericAxisBaseDescriptionMetadata.b = function (a) {
        if (NumericAxisBaseDescriptionMetadata.a == null) {
            NumericAxisBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            NumericAxisBaseDescriptionMetadata.c(NumericAxisBaseDescriptionMetadata.a);
        }
        if (a.k(NumericAxisBaseDescriptionMetadata.a)) {
            return;
        }
        a.ab(NumericAxisBaseDescriptionMetadata.a);
    };
    NumericAxisBaseDescriptionMetadata.c = function (a) {
        AxisDescriptionMetadata.c(a);
        a.item("AutoRangeBufferMode", "ExportedType:string:AxisRangeBufferMode");
        a.item("AutoRangeBufferMode@names", "Auto;Series;SeriesMinimum;SeriesMaximum;None");
        a.item("MinimumValue", "Number:double");
        a.item("ActualMinimumValue", "Number:double");
        a.item("ActualVisibleMinimumValue", "Number:double");
        a.item("MaximumValue", "Number:double");
        a.item("ActualMaximumValue", "Number:double");
        a.item("ActualVisibleMaximumValue", "Number:double");
        a.item("Interval", "Number:double");
        a.item("ActualInterval", "Number:double");
        a.item("MinorInterval", "Number:double");
        a.item("ActualMinorInterval", "Number:double");
        a.item("ReferenceValue", "Number:double");
        a.item("IsLogarithmic", "Boolean");
        a.item("ActualIsLogarithmic", "Boolean");
        a.item("FavorLabellingScaleEnd", "Boolean");
        a.item("LogarithmBase", "Number:int");
        a.item("FormatAbbreviatedLabelRef", "(w:FormatAbbreviatedLabel,wf:FormatAbbreviatedLabel)MethodRef");
        a.item("AbbreviatedLabelFormat", "String");
        a.item("AbbreviatedLabelFormatSpecifiers", "Collection:FormatSpecifier:FormatSpecifierCollection:FormatSpecifier");
        a.item("IsFormattingAbbreviatedLargeNumber", "Boolean");
        a.item("AbbreviateLargeNumbers", "Boolean");
        a.item("ActualMinimumValueChangeRef", "EventRef::actualMinimumValueChange");
        a.item("ActualMaximumValueChangeRef", "EventRef::actualMaximumValueChange");
        a.item("ActualIntervalChangeRef", "EventRef::actualIntervalChange");
        a.item("ActualMinorIntervalChangeRef", "EventRef::actualMinorIntervalChange");
    };
    NumericAxisBaseDescriptionMetadata.d = function (a) {
        NumericAxisBaseDescriptionMetadata.b(a);
        a.ac("NumericAxisBase", NumericAxisBaseDescriptionMetadata.a);
    };
    NumericAxisBaseDescriptionMetadata.$t = markType(NumericAxisBaseDescriptionMetadata, 'NumericAxisBaseDescriptionMetadata');
    NumericAxisBaseDescriptionMetadata.a = null;
    return NumericAxisBaseDescriptionMetadata;
}(Base));
export { NumericAxisBaseDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/NumericAxisBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AxisDescriptionMetadata } from "./AxisDescriptionMetadata";
/**
 * @hidden
 */
var NumericAxisBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NumericAxisBaseDescriptionMetadata, _super);
    function NumericAxisBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NumericAxisBaseDescriptionMetadata.b = function (a) {
        if (NumericAxisBaseDescriptionMetadata.a == null) {
            NumericAxisBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            NumericAxisBaseDescriptionMetadata.c(NumericAxisBaseDescriptionMetadata.a);
        }
        if (a.k(NumericAxisBaseDescriptionMetadata.a)) {
            return;
        }
        a.ac(NumericAxisBaseDescriptionMetadata.a);
    };
    NumericAxisBaseDescriptionMetadata.c = function (a) {
        AxisDescriptionMetadata.c(a);
        a.item("AutoRangeBufferMode", "ExportedType:string:AxisRangeBufferMode");
        a.item("AutoRangeBufferMode@names", "Auto;Series;SeriesMinimum;SeriesMaximum;None");
        a.item("MinimumValue", "Number:double");
        a.item("ActualMinimumValue", "Number:double");
        a.item("ActualVisibleMinimumValue", "Number:double");
        a.item("MaximumValue", "Number:double");
        a.item("ActualMaximumValue", "Number:double");
        a.item("ActualVisibleMaximumValue", "Number:double");
        a.item("Interval", "Number:double");
        a.item("ActualInterval", "Number:double");
        a.item("ActualMaxPrecision", "Number:int");
        a.item("MaxPrecision", "Number:int");
        a.item("ShouldApplyMaxPrecisionWhenZoomed", "Boolean");
        a.item("MinorInterval", "Number:double");
        a.item("ActualMinorInterval", "Number:double");
        a.item("ReferenceValue", "Number:double");
        a.item("IsLogarithmic", "Boolean");
        a.item("ActualIsLogarithmic", "Boolean");
        a.item("FavorLabellingScaleEnd", "Boolean");
        a.item("LogarithmBase", "Number:int");
        a.item("FormatAbbreviatedLabelRef", "(w:FormatAbbreviatedLabel,wf:FormatAbbreviatedLabel)MethodRef");
        a.item("AbbreviatedLabelFormat", "String");
        a.item("AbbreviatedLabelFormatSpecifiers", "Collection:FormatSpecifier:FormatSpecifierCollection:FormatSpecifier");
        a.item("AbbreviatedLabelFormatSpecifiers@mustSetInCode", "WebComponents;Blazor;React;WPF;Angular");
        a.item("IsFormattingAbbreviatedLargeNumber", "Boolean");
        a.item("AbbreviateLargeNumbers", "Boolean");
        a.item("ActualMinimumValueChangeRef", "EventRef::actualMinimumValueChange");
        a.item("ActualMaximumValueChangeRef", "EventRef::actualMaximumValueChange");
        a.item("ActualIntervalChangeRef", "EventRef::actualIntervalChange");
        a.item("ActualMinorIntervalChangeRef", "EventRef::actualMinorIntervalChange");
    };
    NumericAxisBaseDescriptionMetadata.d = function (a) {
        NumericAxisBaseDescriptionMetadata.b(a);
        a.ad("NumericAxisBase", NumericAxisBaseDescriptionMetadata.a);
    };
    NumericAxisBaseDescriptionMetadata.$t = markType(NumericAxisBaseDescriptionMetadata, 'NumericAxisBaseDescriptionMetadata');
    NumericAxisBaseDescriptionMetadata.a = null;
    return NumericAxisBaseDescriptionMetadata;
}(Base));
export { NumericAxisBaseDescriptionMetadata };
